from setuptools import setup

setup(
    name='ork',
    version='0.0.1',
    packages=['ork'],
    package_data={"ork": ["*.json"]},
    url='http://github.com/bonnal-enzo/ork',
    license='Apache 2.0',
    author='Enzo Bonnal',
    author_email='enzobonnal@gmail.com',
    description='Warhammer 40k tool box'
)
